RestRequest

Trait RestRequest 

pub trait RestRequest {
    type Response: DeserializeOwned;
    type QueryParams: Serialize;
    type Body: Serialize;

    // Required methods
    fn path(&self) -> Cow<'static, str>;
    fn method() -> Method;

    // Provided methods
    fn query_params(&self) -> Option<&Self::QueryParams> { ... }
    fn body(&self) -> Option<&Self::Body> { ... }
    fn timeout(&self) -> Duration { ... }
}
Http REST request that can be executed by a RestClient.

Required Associated Types

type Response: DeserializeOwned

Expected response type if this request was successful.

type QueryParams: Serialize

Serialisable query parameters type - use unit struct () if not required for this request.

type Body: Serialize

Serialisable Body type - use unit struct () if not required for this request.

Required Methods

fn path(&self) -> Cow<'static, str>

Additional Url path to the resource.

fn method() -> Method

Http reqwest::Method of this request.

Provided Methods

fn query_params(&self) -> Option<&Self::QueryParams>

Optional query parameters for this request.

fn body(&self) -> Option<&Self::Body>

Optional Body for this request.

fn timeout(&self) -> Duration

Http request timeout Duration.

Takes &self so an implementation may derive the timeout from per-instance/config state (e.g. an operator-tunable timeout captured at construction). The default returns the compile-time [DEFAULT_HTTP_REQUEST_TIMEOUT] and ignores self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors