Module de

Module de 

Deserialisation transformers (json, protobuf, etc.) and associated logic.

Modules

error
Deserialisation error variants.

Structs

DeJson
JSON deserialiser.
DeProtobuf
Protobuf deserialiser.

Traits

Deserialiser
Trait for types that can deserialise input payload data (eg/ strings, bytes, etc.) into structured Rust types.

Functions

datetime_utc_from_epoch_duration
Determine the DateTime<Utc> from the provided Duration since the epoch.
de_str
Deserialise a String as the desired type.
de_str_f64_epoch_ms_as_datetime_utc
Deserialise a &str “f64” milliseconds value as DateTime<Utc>.
de_str_f64_epoch_s_as_datetime_utc
Deserialise a &str “f64” seconds value as DateTime<Utc>.
de_str_u64_epoch_ms_as_datetime_utc
Deserialise a &str “u64” milliseconds value as DateTime<Utc>.
de_u64_epoch_ms_as_datetime_utc
Deserialise a u64 milliseconds value as DateTime<Utc>.
extract_next
Assists deserialisation of sequences by attempting to extract & parse the next element in the provided sequence.