Module on_connect_err

Module on_connect_err 

Connection error handling.

Structs

ConnectError
Connection error with reconnection attempt count.
OnConnectErr
Stream adapter that handles connection errors using a custom error handler.

Enums

ConnectErrorAction
Action to take in response to a connection error.
ConnectErrorKind
Connection error variants.

Traits

ConnectErrorHandler
Handles connection errors and determines the appropriate ConnectErrorAction.