Module on_stream_err

Module on_stream_err 

Stream error handling.

Structs

OnStreamErr
Stream wrapper that applies error handling to a Result stream.

Enums

StreamErrorAction
Action to take in response to a stream error.

Traits

StreamErrorHandler
Handles stream errors and determines the appropriate StreamErrorAction.