Module subscription

Module subscription 

Defines a SubscriptionId new type representing a unique SmolStr identifier for a data stream (market data, account data) that has been subscribed to.

Structs

SubscriptionId
New type representing a unique String identifier for a stream that has been subscribed to. This is used to identify data structures received over the socket.