Validator

Trait Validator 

pub trait Validator {
    type Error;

    // Required method
    fn validate(self) -> Result<Self, Self::Error>
       where Self: Sized;
}
Validators are capable of determining if their internal state is satisfactory to fulfill some use case defined by the implementor.

Required Associated Types

Required Methods

fn validate(self) -> Result<Self, Self::Error>
where Self: Sized,

Check if Self is valid for some use case.

Implementors