Connection error handling.
Structs
- Connect
Error - Connection error with reconnection attempt count.
- OnConnect
Err - Stream adapter that handles connection errors using a custom error handler.
Enums
- Connect
Error Action - Action to take in response to a connection error.
- Connect
Error Kind - Connection error variants.
Traits
- Connect
Error Handler - Handles connection errors and determines the appropriate
ConnectErrorAction.